use std::{
    io::{self, Read, Write},
    net::TcpStream,
};

pub struct Client {
    stream: TcpStream,
}

impl Client {
    pub(crate) fn new(stream: TcpStream) -> Self {
        Client { stream }
    }

    // basically an alias for write (might remove)
    pub(crate) fn write_bytes(&mut self, mut bytes: Vec<u8>) -> io::Result<usize> {
        bytes.extend(b"\r\n");
        self.stream.write(&bytes)
    }

    pub(crate) fn write_string(&mut self, mut string: String) -> io::Result<usize> {
        string.push_str("\r\n");
        self.stream.write(string.as_bytes())
    }
}

impl Read for Client {
    fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
        self.stream.read(buf)
    }
}

impl Write for Client {
    fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
        self.stream.write(buf)
    }

    fn flush(&mut self) -> io::Result<()> {
        self.stream.flush()
    }
}
